@@ -1,10 +1,9 @@
 from pathlib import Path
 from typing import Optional
 
-from textacy.preprocessing import normalize_quotation_marks
+from textacy.preprocessing import normalize_quotation_marks  # type: ignore
 
-
-from .base import BaseProcessor
+from textdatasetcleaner.processors.base import BaseProcessor
 
 
 class NormalizeQuotationMarksProcessor(BaseProcessor):
@@ -13,6 +12,4 @@ class NormalizeQuotationMarksProcessor(BaseProcessor):
     __processor_type__ = 'line'
 
     def process_line(self, line: str) -> Optional[str]:
-        line = normalize_quotation_marks(line)
-
-        return line
+        return normalize_quotation_marks(line)
