@@ -2,9 +2,9 @@ import string
 from pathlib import Path
 from typing import Optional
 
-from textacy.preprocessing import normalize_repeating_chars
+from textacy.preprocessing import normalize_repeating_chars  # type: ignore
 
-from .base import BaseProcessor
+from textdatasetcleaner.processors.base import BaseProcessor
 
 
 # prevent remove '...'
@@ -25,5 +25,7 @@ class NormalizeRepeatingCharsProcessor(BaseProcessor):
                 line = normalize_repeating_chars(line, chars=punct, maxn=1)
         if '....' in line:
             line = normalize_repeating_chars(line, chars='.', maxn=3)
+        elif '..' in line:
+            line = line.replace('..', '...')
 
         return line
