@@ -1,9 +1,9 @@
 from pathlib import Path
 from typing import Optional
 
-from textacy.preprocessing import remove_accents
+from textacy.preprocessing import remove_accents  # type: ignore
 
-from .base import BaseProcessor
+from textdatasetcleaner.processors.base import BaseProcessor
 
 
 class RemoveAccentsProcessor(BaseProcessor):
@@ -12,6 +12,4 @@ class RemoveAccentsProcessor(BaseProcessor):
     __processor_type__ = 'line'
 
     def process_line(self, line: str) -> Optional[str]:
-        line = remove_accents(line)
-
-        return line
+        return remove_accents(line)
